#ifndef INCLUDE_SUPPORT_H
#define INCLUDE_SUPPORT_H
/* ----------------------------------------------------------------------------
 * support.h
 * prototypes and definitions for support.c.
 *
 * Copyright 2002 Matthias Grimm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 * ----------------------------------------------------------------------------*/

#define CPFLG_NONE	         0
#define CPFLG_MAYBEMISSED    1
#define CPFLG_PBBONLY		 2

struct ChildData {
	char **argv;
	GPid pid;
	gint twatch;
	gint cwatch;
	gint ref;     /* reference count */
	gint rc;      /* child's return code, or -1 */
};

/* prototypes */
int copy_path (char *source, char *dest, int type, int flags);
int call_script (char* template, ...);

#endif    /* INCLUDE_SUPPORT_H */
